#import <objectbase/SwarmObject.h>
#import <gui.h>

@interface Tree: SwarmObject
{

@public

//              Species
//-----------------------------------

  id species;
   
//              Mortality
//-----------------------------------

  int age;

//              Disturbance
//-----------------------------------

  int totalHeat;

//              Growth
//----------------------------------

//              Fecundity
//-----------------------------------

  int seedingCounter;

//              Location
//-----------------------------------

  int x, y;			

//           Visualization
//-----------------------------------

//             SpeedHack
//-----------------------------------

  member_t listMembership;
}

- setSpecies: aSpecies;
- setAge: (int)anAge;
- setSeedingCounter: (int)aYear;
- createEnd;

- (int)getAge; 
- (int)getX;
- (int)getY;
- getSpecies;
- clearSeedingCounter;
- (int) incSeedingCounter;
- (int) incAge;
- setX: (int)x Y: (int)y;			
- step;
- burn;
- fireWithHeat: (int)theHeat;
- drawSelfOn: (id <Raster>)r;
- (int)getSpeciesIdentifier;
@end
